@@ -22,12 +22,3 @@ try:
         version = 'devel'
 except DistributionNotFound:
     version = "devel"
-
-try:
-    from logserviceclient.utils.logger import initLogger
-    try:
-        initLogger(pkg)
-    except Exception:
-        logging.warning("Log service client was not initialized properly")
-except ImportError:
-    pass
